@@ -1,14 +1,12 @@
 import os
 
-__version__ = "1.0.0"
+__version__ = "1.0.1"
 
 GOOGLE_APPLICATION_CREDENTIALS = os.getenv('GOOGLE_APPLICATION_CREDENTIALS', None)
 SERVICE_ACCOUNT_EMAIL = os.getenv('SERVICE_ACCOUNT_EMAIL', None)
 SERVICE_NAME_AUDIENCE = os.getenv('SERVICE_NAME_AUDIENCE', None)
 
-SERVICE_ACCOUNT_FILE = '/auth.json'.format(
-    os.path.dirname(os.path.abspath('secret'))
-)
+SERVICE_ACCOUNT_FILE = '{}/auth.json'.format(os.path.dirname(os.path.abspath('secret')))
 
 try:
     with open(SERVICE_ACCOUNT_FILE) as f:
